fnss.traffic.trafficmatrices.TrafficMatrixSequence.get — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.traffic.trafficmatrices.TrafficMatrixSequence.get

`TrafficMatrixSequence.` `get`(i)

  Return a specific traffic matrix in a specific position of the sequence

  Parameters : | i : int The index of the traffic matrix
  Returns : | tm : TrafficMatrix

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »